The preferred configuration is to prevent the use of unauthorised HTTP
methods by utilising the `<LimitExcept>` directive.

This directive
uses a whitelisting approach to permit HTTP methods while blocking all
others not listed in the directive, and will therefor block any method
tampering attempts.

Most commonly, the only HTTP methods required for
most scenarios are `GET` and `POST`. An example of permitting these
HTTP methods is: `<LimitExcept POST GET> require valid-user
</LimitExcept>`